@@ -2,6 +2,7 @@
 from dataclasses import dataclass
 
 from aiohttp.client import ClientTimeout
+from aiohttp.hdrs import IF_NONE_MATCH
 
 from .base import HaVersionBase
 from .consts import (
@@ -11,8 +12,8 @@ from .consts import (
     DATA_RELEASE_NOTES,
     DATA_RELEASE_TITLE,
     DEFAULT_HEADERS,
-    HaVersionSource,
 )
+from .exceptions import HaVersionNotModifiedException
 
 URL = "https://www.home-assistant.io/version.json"
 
@@ -21,15 +22,22 @@ URL = "https://www.home-assistant.io/version.json"
 class HaVersionHaio(HaVersionBase):
     """Handle versions for the home-assistant.io source."""
 
-    source = HaVersionSource.HAIO
-
     async def fetch(self, **kwargs):
         """Logic to fetch new version data."""
+        headers = DEFAULT_HEADERS
+        if (etag := kwargs.get("etag")) is not None:
+            headers[IF_NONE_MATCH] = etag
+
         request = await self.session.get(
             url=URL,
-            headers=DEFAULT_HEADERS,
+            headers=headers,
             timeout=ClientTimeout(total=self.timeout),
         )
+        self._etag = request.headers.get("Etag")
+
+        if request.status == 304:
+            raise HaVersionNotModifiedException
+
         self._data = await request.json()
 
     def parse(self):
